@@ -1,7 +1,7 @@
 """
 Type annotations for cloud9 service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloud9/type_defs/)
 
 Usage::
 
@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     ConnectionTypeType,
     EnvironmentLifecycleStatusType,
@@ -39,6 +41,7 @@ __all__ = (
     "CreateEnvironmentMembershipResultTypeDef",
     "DeleteEnvironmentMembershipRequestRequestTypeDef",
     "DeleteEnvironmentRequestRequestTypeDef",
+    "DescribeEnvironmentMembershipsRequestDescribeEnvironmentMembershipsPaginateTypeDef",
     "DescribeEnvironmentMembershipsRequestRequestTypeDef",
     "DescribeEnvironmentMembershipsResultTypeDef",
     "DescribeEnvironmentStatusRequestRequestTypeDef",
@@ -48,6 +51,7 @@ __all__ = (
     "EnvironmentLifecycleTypeDef",
     "EnvironmentMemberTypeDef",
     "EnvironmentTypeDef",
+    "ListEnvironmentsRequestListEnvironmentsPaginateTypeDef",
     "ListEnvironmentsRequestRequestTypeDef",
     "ListEnvironmentsResultTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -133,6 +137,17 @@ DeleteEnvironmentRequestRequestTypeDef = TypedDict(
     },
 )
 
+DescribeEnvironmentMembershipsRequestDescribeEnvironmentMembershipsPaginateTypeDef = TypedDict(
+    "DescribeEnvironmentMembershipsRequestDescribeEnvironmentMembershipsPaginateTypeDef",
+    {
+        "userArn": str,
+        "environmentId": str,
+        "permissions": Sequence[PermissionsType],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 DescribeEnvironmentMembershipsRequestRequestTypeDef = TypedDict(
     "DescribeEnvironmentMembershipsRequestRequestTypeDef",
     {
@@ -245,6 +260,14 @@ class EnvironmentTypeDef(_RequiredEnvironmentTypeDef, _OptionalEnvironmentTypeDe
     pass
 
 
+ListEnvironmentsRequestListEnvironmentsPaginateTypeDef = TypedDict(
+    "ListEnvironmentsRequestListEnvironmentsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListEnvironmentsRequestRequestTypeDef = TypedDict(
     "ListEnvironmentsRequestRequestTypeDef",
     {
